# Changelog

## 0.1.0 (2026-03-20)

Initial release.

- MLflow tracking hook: hierarchical runs, per-sample metrics, model usage, artifact logging
- MLflow tracing hook: execution span tree with model calls, tool calls, scoring
- Auto-registration via Inspect AI entry points
- 33 unit tests
